#
# spec file for package xaos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define alt_name XaoS
Name:           xaos
Version:        4.3.2
Release:        1.4
Summary:        Powerful fractal generator
License:        GPL-2.0-or-later
Group:          Amusements/Toys/Graphics
URL:            https://xaos-project.github.io
Source0:        https://github.com/xaos-project/XaoS/archive/release-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  qt6-tools-linguist
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Widgets)
Provides:       %{alt_name}

%description
XaoS is a fast portable real-time interactive fractal zoomer. It
displays the Mandelbrot set (among other escape time fractals) and
allows you to zoom smoothly into the fractal.  Various coloring modes
are provided for both the points inside and outside the selected set.
In addition, switching between Julia and Mandelbrot fractal types and
displaying planes is provided.

%prep
%setup -q -n XaoS-release-%{version}

%build
%qmake6 PREFIX=%{_prefix}
%qmake6_build STRIP=%{_bindir}/strip

%install
# Binary
%qmake6_install

# Examples
mkdir -p %{buildroot}%{_datadir}/%{alt_name}
find examples -name \'*.xpf\' -exec cp {} %{buildroot}%{_datadir}/%{alt_name}/examples \;

# Data; Datapath forced to %%{alt_name} (not configurable)
install -D --mode 0644 --target-directory %{buildroot}%{_datadir}/%{alt_name}/catalogs catalogs/*.cat
cp --archive examples tutorial %{buildroot}%{_datadir}/%{alt_name}

# Icon, .desktop, AppData
install -D --mode 0644 --target-directory %{buildroot}%{_datadir}/metainfo xdg/%{name}.appdata.xml
install -D --mode 0644 --target-directory %{buildroot}%{_datadir}/applications xdg/*.desktop
install -D --mode 0644 --target-directory %{buildroot}%{_datadir}/pixmaps xdg/%{name}.png

# Man
install -D --mode 0644 --target-directory %{buildroot}%{_mandir}/man6 doc/%{name}.6

%fdupes %{buildroot}%{_datadir}/%{alt_name}/examples/

%files
%doc CREDITS.md NEWS doc/README
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{alt_name}/
%{_datadir}/applications/*.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man6/%{name}.6%{?ext_man}

%changelog
* Sat Jan 27 2024 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 4.3.2:
  * Turkish translation.
  * Ctrl-C copies the current position to the clipboard as an URL at xaos.app.
  * Some new keyboard shortcuts: Shift-F1 for Info on current fractal and
    Ctrl-+ for Autopilot.
  * "Mathematical" coordinates of the mouse are shown in the status.
  * Contributor's list is linked in Help > About.
* Wed Nov  1 2023 munix9@googlemail.com
- Fix build on Factory/TW: Add STRIP=%%{_bindir}/strip to %%qmake6_build
* Sun Oct  8 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.3.1:
  * Two new examples.
  * Bug Fix: Example files are loaded properly now.
* Sat Sep 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.3:
  * Migration to Qt 6.
  * Progress bar for time consuming operations (only on native
    platforms).
  * Bug Fixes:
  - Example files are loaded properly even if XaoS is not
    installed (that is, the examples are not flattened).
  - User formulas are not duplicated in the history.
- Switch to Qt6 for building; use qmake6 macros.
- Install examples and run fdupes to reduce duplicate files.
* Sat Feb 27 2021 antoine.belvire@opensuse.org
- Bump Qt minimal required version to 5.7: Code references
  QLocale::DefaultNumberOptions which does not exist before 5.7.
* Thu Feb 25 2021 antoine.belvire@opensuse.org
- Update to version 4.2.1:
  * A lot of changes happened since 3.6.
  * Notably UI is now based on Qt.
  * See installed NEWS file for details.
- Drop obsolete patches:
  * xaos-3.5-strip.patch
  * fix-prototypes.diff
  * xaos-fix-implicit-decl.patch
- Drop obsolete sources:
  * xaos.desktop
  * xaos.png
  * xaos.sh
* Tue Sep 11 2018 antoine.belvire@opensuse.org
- Fix install_info_delete macro usage.
* Wed Mar 14 2018 crrodriguez@opensuse.org
- Replace xorg-x11-devel BuildRequires by pkgconfig(x11),
  pkgconfig(xext)
* Sat Apr 11 2015 p.drouand@gmail.com
- Update to version 3.6
  * Supporting libpng >= 1.5 and 1.6
  * Various bug fixes
  * New fractal types
- Update Url
- Use download Url as source
- Remove xaos-libpng15.patch and xaos-libpng16.patch; fixed on upstream
  release
- Add xaos-fix-implicit-decl.patch
- Remove superfluous xorg-x11 build require
- Split out translation files
- Remove redundant %%clean section
- Fix with -fno-strict-aliasing has the new version is likely to break
  with new gcc
* Mon Mar  2 2015 sfalken@opensuse.org
- Changed desktop category to clear brp-check-suse failure
* Tue Apr  9 2013 pgajdos@suse.com
- builds also with libpng16
* Tue Sep  4 2012 pgajdos@suse.com
- builds also with libpng15
  * libpng15.patch
* Thu Jun 14 2012 coolo@suse.com
- fix protoype with new gcc
* Tue Jul 21 2009 AxelKoellhofer@web.de
- updated to 3.5
  o Fixed crash bug when using -render command line option with user formulas
  o Removed support for unmaintained platforms (DOS, BeOS, Plan 9, etc.)
  o Updated documentation to reflect infrastructure changes
  (Discussion and issue tracking have moved to Google Groups and Google Code)
  o Additional fractal examples by J.B. Langston
  ... see NEWS for more
- obsolete patch removed
* Thu Jun  4 2009 AxelKoellhofer@web.de
- spec cleanup
- obsolete patches removed
- convert all xpf-files to UNIX format
- added fdupes and dos2unix to BuildRequires
* Tue Feb 26 2008 crrodriguez@suse.de
- use find_lang macro
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 schwab@suse.de
- Fix last change.
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
- Fix missing declarations.
* Mon Aug 22 2005 nadvornik@suse.cz
- added icon [#106118]
* Thu Apr 14 2005 nadvornik@suse.cz
- fixed to compile with gcc4
* Fri Apr  1 2005 nadvornik@suse.cz
- removed unused header file with problematic license [75433]
* Tue Mar 30 2004 nadvornik@suse.cz
- added wrapper script to run it with ISO-8859-X locales as it does not
  work with UTF-8
* Fri Feb 27 2004 ro@suse.de
- fix build with regparm changes
* Tue Feb 17 2004 nadvornik@suse.cz
- added desktop file
- built as user
* Tue Jul 29 2003 nadvornik@suse.cz
- updated to 3.1
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Feb 11 2003 nadvornik@suse.cz
- added install_info macros
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Nov 12 2001 ro@suse.de
- no svgalib
* Fri May 18 2001 nadvornik@suse.cz
- fixed cast warnings and include files for ia64
* Mon Dec 11 2000 ro@suse.de
- changed neededforbuild <aalibdev> to <aalib-devel>
* Mon Oct  9 2000 nadvornik@suse.cz
- removed suid bit, used %%doc for man and info, used RPM_OPT_FLAGS
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
- used bzip2
* Mon Sep  4 2000 schwab@suse.de
- Add %%suse_update_config.
* Thu May 18 2000 nadvornik@suse.cz
- used %%{_defaultdocdir}
- fixed filelist
- changed Group tag
* Tue Apr 11 2000 nadvornik@suse.cz
- added URL
* Thu Mar 23 2000 nadvornik@suse.cz
- added BuildRoot
- added source url
* Tue Feb  1 2000 ro@suse.de
- man,info to usr/share
* Tue Feb  1 2000 fehr@suse.de
- change for new gcc 2.95.2
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 uli@suse.de
- disabled svgalib driver for PPC
* Wed Mar 17 1999 uli@suse.de
- update 2.2 -> 3.0
- enabled svgalib/aalib drivers
* Tue Oct  7 1997 fehr@suse.de
- now works with (a)build
* Wed May 14 1997 fehr@suse.de
- added version 2.2 to distribution
